[−][src]Crate ttv_chat
Modules
| commands | Provides |
| decoder | Decoding utilities. |
| encoder | Encoding utilies |
| irc | IRC message parsing. |
| maybe_owned | This is a |
| messages | Twitch messages that can be parsed from |
| rate_limit | A simple leaky-bucket style token-based rate limiter |
| runner | A set of runners for managing a |
| twitch | Common Twitch types |
Structs
| Decoder | A decoder over |
| Encoder | A synchronous encoder |
| IrcMessage | A raw irc message |
| UserConfig | User configuration for 'registering' with Twitch |
Enums
| DecodeError | An error produced by a Decoder. |
| MessageError | An invalid message was either provided, or could not be parsed |
| RunnerError | An error returned by a Runner |
| Status | Status produced by the loop |
Constants
| ANONYMOUS_LOGIN | An anonymous login. |
| TWITCH_IRC_ADDRESS | The Twitch IRC address for non-TLS connections |
| TWITCH_IRC_ADDRESS_TLS | The Twitch IRC address for TLS connections |
| TWITCH_TLS_DOMAIN | A TLS domain for Twitch |
| TWITCH_WS_ADDRESS | The Twitch WebSocket address for non-TLS connections |
| TWITCH_WS_ADDRESS_TLS | The Twitch WebSocket address for TLS connections |
Traits
| Encodable | A trait to allow writing messags to any |
| FromIrcMessage | A trait to convert an |
| IntoIrcMessage | A trait to convert a |
| IntoOwned | Converts a borrowed type into an owned type. e.g. |
| PrivmsgExt | Extensions to the |
| Validator | This trait is provided as an easy way of defining your own custom events. |